pub fn present(surface_texture: SurfaceTexture) -> Result<(), RenderError>Expand description
Present the rendered frame to the swapchain.
Call this after encoding commands that render into the acquired surface texture.
pub fn present(surface_texture: SurfaceTexture) -> Result<(), RenderError>Present the rendered frame to the swapchain.
Call this after encoding commands that render into the acquired surface texture.