pub struct RenderInstanceData<'a> {
pub device: Device,
pub queue: Queue,
pub surface: Option<Surface<'a>>,
pub adapter: Adapter,
pub instance: Instance,
pub surface_config: Option<SurfaceConfiguration>,
}Expand description
Device, queue, surface, and adapter bundle used to create GPU resources.
This is the handle you pass into buffers, textures, command buffers, and pipelines.
The type is intentionally lightweight to clone/read behind the Arc<RwLock<_>> in
RenderInstance.
use wde_wgpu::{buffer::{Buffer, BufferUsage}, instance::{create_instance, RenderInstanceData}};
let instance = create_instance("docs", Some(&window)).await;
let data: std::sync::RwLockReadGuard<'_, RenderInstanceData> = instance.data.read().unwrap();
let mut buf = Buffer::new(&data, "hello", 16, BufferUsage::UNIFORM | BufferUsage::COPY_DST, None);
buf.write(&data, &[1, 2, 3, 4], 0);Fields
device: DeviceDevice of the instance.
queue: QueueQueue of the instance.
surface: Option<Surface<'a>>Surface of the instance.
adapter: AdapterAdapter of the instance.
instance: InstanceInstance of the GPU device.
surface_config: Option<SurfaceConfiguration>Surface configuration of the instance.